from PySide6.QtGui import QGuiApplication, QAction
from PySide6.QtQml import QQmlApplicationEngine
from PySide6 import QtWidgets, QtCore

from ui.settings import SettingsDialog
class LibraryDashboard(QtWidgets.QWidget):
    def __init__(self):
        super().__init__()

        # Central widget and layout
        main_layout = QtWidgets.QVBoxLayout(self)

        # Title label
        title_label = QtWidgets.QLabel("Dashboard", self)
        title_label.setAlignment(QtCore.Qt.AlignCenter)
        title_label.setStyleSheet("font-size: 20px; font-weight: bold; color: #0078D4;")
        main_layout.addWidget(title_label)


        # Available books list
        available_label = QtWidgets.QLabel("Available Books")
        available_label.setStyleSheet("font-size: 16px;")
        main_layout.addWidget(available_label)

        # Search bar
        self.search_input = QtWidgets.QLineEdit()
        self.search_input.setPlaceholderText("Type to search...")
        self.search_input.textChanged.connect(self.filter_books)
        main_layout.addWidget(self.search_input)


        self.available_books_list = QtWidgets.QListWidget()
        self.books = ["Book One", "Book Two", "Book Three", "Book Four",
                      "Book Five", "Book Six", "Book Seven", "Book Eight"]
        
        self.available_books_list.addItems(self.books)
        self.available_books_list.itemClicked.connect(self.edit_book)
        self.available_books_list.setStyleSheet("""
            QListWidget {
                font-size: 14px;
            }
            QListWidget::item {
                padding: 5px;
            }
            QListWidget::item:hover {
                background-color: palette(highlight);
                color: palette(highlighted-text);
            }
            """)
        main_layout.addWidget(self.available_books_list)

        # Borrowed books list
        borrowed_label = QtWidgets.QLabel("Currently Borrowed Books")
        borrowed_label.setStyleSheet("font-size: 16px;")
        main_layout.addWidget(borrowed_label)

        self.borrowed_books_list = QtWidgets.QListWidget()
        self.borrowed_books_list.addItems(["Book Two", "Book Four"])
        self.borrowed_books_list.itemClicked.connect(self.return_book)
        main_layout.addWidget(self.borrowed_books_list)

        # Buttons for actions
        button_layout = QtWidgets.QHBoxLayout()
        register_member_button = QtWidgets.QPushButton("Add New Member")
        register_member_button.clicked.connect(self.register_member)
        button_layout.addWidget(register_member_button)

        add_borrow_record_button = QtWidgets.QPushButton("Add Borrow Record")
        add_borrow_record_button.clicked.connect(self.add_borrow_record)
        button_layout.addWidget(add_borrow_record_button)

        main_layout.addLayout(button_layout)

    def filter_books(self, text):
        """Filter the available books list based on the search input."""
        self.available_books_list.clear()
        filtered_books = [book for book in self.books if text.lower() in book.lower()]
        self.available_books_list.addItems(filtered_books)

    # Slots for button actions
    def edit_book(self, item):
        QtWidgets.QMessageBox.information(self, "Edit Book", f"Edit details for '{item.text()}'.")

    def return_book(self, item):
        QtWidgets.QMessageBox.information(self, "Return Book", f"Mark '{item.text()}' as returned.")

    def register_member(self):
        QtWidgets.QMessageBox.information(self, "Add Member", "Open dialog to register a new member.")

    def add_borrow_record(self):
        QtWidgets.QMessageBox.information(self, "Add Borrow Record", "Open dialog to add a borrow record.")

